==> kdevplatform-0.9.91-i486-1.txz: install/doinst.sh <==

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
fi

( cd usr/lib ; rm -rf libkdevplatforminterfaces.so.1 )
( cd usr/lib ; ln -sf libkdevplatforminterfaces.so.1.0.0 libkdevplatforminterfaces.so.1 )
( cd usr/lib ; rm -rf libkdevplatformveritas.so.1 )
( cd usr/lib ; ln -sf libkdevplatformveritas.so.1.0.0 libkdevplatformveritas.so.1 )
( cd usr/lib ; rm -rf libkdevplatformlanguage.so )
( cd usr/lib ; ln -sf libkdevplatformlanguage.so.1 libkdevplatformlanguage.so )
( cd usr/lib ; rm -rf libkdevplatformshell.so.1 )
( cd usr/lib ; ln -sf libkdevplatformshell.so.1.0.0 libkdevplatformshell.so.1 )
( cd usr/lib ; rm -rf libkdevplatformvcs.so )
( cd usr/lib ; ln -sf libkdevplatformvcs.so.1 libkdevplatformvcs.so )
( cd usr/lib ; rm -rf libkdevplatformlanguage.so.1 )
( cd usr/lib ; ln -sf libkdevplatformlanguage.so.1.0.0 libkdevplatformlanguage.so.1 )
( cd usr/lib ; rm -rf libkdevplatformproject.so )
( cd usr/lib ; ln -sf libkdevplatformproject.so.1 libkdevplatformproject.so )
( cd usr/lib ; rm -rf libkdevplatformshell.so )
( cd usr/lib ; ln -sf libkdevplatformshell.so.1 libkdevplatformshell.so )
( cd usr/lib ; rm -rf libkdevplatformproject.so.1 )
( cd usr/lib ; ln -sf libkdevplatformproject.so.1.0.0 libkdevplatformproject.so.1 )
( cd usr/lib ; rm -rf libkdevplatformvcs.so.1 )
( cd usr/lib ; ln -sf libkdevplatformvcs.so.1.0.0 libkdevplatformvcs.so.1 )
( cd usr/lib ; rm -rf libkdevplatformutil.so )
( cd usr/lib ; ln -sf libkdevplatformutil.so.1 libkdevplatformutil.so )
( cd usr/lib ; rm -rf libkdevplatformtestshell.so )
( cd usr/lib ; ln -sf libkdevplatformtestshell.so.1 libkdevplatformtestshell.so )
( cd usr/lib ; rm -rf libsublime.so )
( cd usr/lib ; ln -sf libsublime.so.1 libsublime.so )
( cd usr/lib ; rm -rf libkdevplatformoutputview.so )
( cd usr/lib ; ln -sf libkdevplatformoutputview.so.1 libkdevplatformoutputview.so )
( cd usr/lib ; rm -rf libkdevplatforminterfaces.so )
( cd usr/lib ; ln -sf libkdevplatforminterfaces.so.1 libkdevplatforminterfaces.so )
( cd usr/lib ; rm -rf libkdevplatformutil.so.1 )
( cd usr/lib ; ln -sf libkdevplatformutil.so.1.0.0 libkdevplatformutil.so.1 )
( cd usr/lib ; rm -rf libkdevplatformveritas.so )
( cd usr/lib ; ln -sf libkdevplatformveritas.so.1 libkdevplatformveritas.so )
( cd usr/lib ; rm -rf libsublime.so.1 )
( cd usr/lib ; ln -sf libsublime.so.1.0.0 libsublime.so.1 )
( cd usr/lib ; rm -rf libkdevplatformoutputview.so.1 )
( cd usr/lib ; ln -sf libkdevplatformoutputview.so.1.0.0 libkdevplatformoutputview.so.1 )
( cd usr/lib ; rm -rf libkdevplatformtestshell.so.1 )
( cd usr/lib ; ln -sf libkdevplatformtestshell.so.1.0.0 libkdevplatformtestshell.so.1 )

==> kdevplatform-1.0.0-i486-1.txz: install/doinst.sh <==

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
fi

( cd usr/lib ; rm -rf libkdevplatformoutputview.so.1 )
( cd usr/lib ; ln -sf libkdevplatformoutputview.so.1.0.0 libkdevplatformoutputview.so.1 )
( cd usr/lib ; rm -rf libkdevplatformshell.so.1 )
( cd usr/lib ; ln -sf libkdevplatformshell.so.1.0.0 libkdevplatformshell.so.1 )
( cd usr/lib ; rm -rf libkdevplatforminterfaces.so.1 )
( cd usr/lib ; ln -sf libkdevplatforminterfaces.so.1.0.0 libkdevplatforminterfaces.so.1 )
( cd usr/lib ; rm -rf libkdevplatformlanguage.so.1 )
( cd usr/lib ; ln -sf libkdevplatformlanguage.so.1.0.0 libkdevplatformlanguage.so.1 )
( cd usr/lib ; rm -rf libkdevplatformlanguage.so )
( cd usr/lib ; ln -sf libkdevplatformlanguage.so.1 libkdevplatformlanguage.so )
( cd usr/lib ; rm -rf libsublime.so.1 )
( cd usr/lib ; ln -sf libsublime.so.1.0.0 libsublime.so.1 )
( cd usr/lib ; rm -rf libkdevplatformdebugger.so )
( cd usr/lib ; ln -sf libkdevplatformdebugger.so.1 libkdevplatformdebugger.so )
( cd usr/lib ; rm -rf libkdevplatformtests.so.1 )
( cd usr/lib ; ln -sf libkdevplatformtests.so.1.0.0 libkdevplatformtests.so.1 )
( cd usr/lib ; rm -rf libkdevplatformvcs.so.1 )
( cd usr/lib ; ln -sf libkdevplatformvcs.so.1.0.0 libkdevplatformvcs.so.1 )
( cd usr/lib ; rm -rf libsublime.so )
( cd usr/lib ; ln -sf libsublime.so.1 libsublime.so )
( cd usr/lib ; rm -rf libkdevplatforminterfaces.so )
( cd usr/lib ; ln -sf libkdevplatforminterfaces.so.1 libkdevplatforminterfaces.so )
( cd usr/lib ; rm -rf libkdevplatformproject.so.1 )
( cd usr/lib ; ln -sf libkdevplatformproject.so.1.0.0 libkdevplatformproject.so.1 )
( cd usr/lib ; rm -rf libkdevplatformutil.so.1 )
( cd usr/lib ; ln -sf libkdevplatformutil.so.1.0.0 libkdevplatformutil.so.1 )
( cd usr/lib ; rm -rf libkdevplatformtests.so )
( cd usr/lib ; ln -sf libkdevplatformtests.so.1 libkdevplatformtests.so )
( cd usr/lib ; rm -rf libkdevplatformdebugger.so.1 )
( cd usr/lib ; ln -sf libkdevplatformdebugger.so.1.0.0 libkdevplatformdebugger.so.1 )
( cd usr/lib ; rm -rf libkdevplatformshell.so )
( cd usr/lib ; ln -sf libkdevplatformshell.so.1 libkdevplatformshell.so )
( cd usr/lib ; rm -rf libkdevplatformutil.so )
( cd usr/lib ; ln -sf libkdevplatformutil.so.1 libkdevplatformutil.so )
( cd usr/lib ; rm -rf libkdevplatformoutputview.so )
( cd usr/lib ; ln -sf libkdevplatformoutputview.so.1 libkdevplatformoutputview.so )
( cd usr/lib ; rm -rf libkdevplatformvcs.so )
( cd usr/lib ; ln -sf libkdevplatformvcs.so.1 libkdevplatformvcs.so )
( cd usr/lib ; rm -rf libkdevplatformproject.so )
( cd usr/lib ; ln -sf libkdevplatformproject.so.1 libkdevplatformproject.so )
